#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cliui = __importStar(require("cliui"));
const fs_1 = require("fs");
const js_yaml_1 = require("js-yaml");
const path = __importStar(require("path"));
const title_case_1 = require("title-case");
const util_1 = require("util");
const windowSize = __importStar(require("window-size"));
const yargs_1 = require("yargs");
const readDirP = util_1.promisify(fs_1.readdir);
const readFileP = util_1.promisify(fs_1.readFile);
const statsP = util_1.promisify(fs_1.stat);
function resolveDotted(obj, dotted) {
    const parts = dotted
        .split('.')
        .map(p => p.trim())
        .map(p => p.match(/^\d+$/) && parseInt(p, 10) || p);
    let v = obj;
    parts.forEach(p => v = v && v[p] || undefined);
    return v;
}
yargs_1.command('*', 'List resource limits per service', (yargs) => yargs
    .option('dir', {
    alias: 'd',
    default: '.'
}), async (argv) => {
    const dir = path.normalize(path.resolve(argv.dir));
    const folders = await readDirP(dir);
    const composeFiles = await Promise.all(folders
        .map(folder => path.join(dir, folder, 'docker-compose.yml'))
        .map(composeFile => statsP(composeFile)
        .then(stats => stats.isFile && readFileP(composeFile, 'utf8') || null)
        .then(content => [composeFile, content])
        .catch(() => null)));
    const resources = [].concat(...composeFiles
        .filter(file => !!file)
        .map(([file, content]) => [file, js_yaml_1.safeLoad(content)])
        .map(([file, config]) => {
        const services = config && config.services || {};
        return Object.keys(services)
            .map(name => ({
            file,
            name,
            cpuLimit: resolveDotted(services[name], 'deploy.resources.limits.cpus') || 0,
            cpuReservation: resolveDotted(services[name], 'deploy.resources.reservations.cpus') || 0,
            memLimit: resolveDotted(services[name], 'deploy.resources.limits.memory') || 0,
            memReservation: resolveDotted(services[name], 'deploy.resources.reservations.memory') || 0
        }));
    }));
    if (resources.length < 1)
        return console.log('No compose files found');
    const columns = Object.keys(resources[0]);
    const out = [
        columns.map(c => title_case_1.titleCase(c)).join(' \t'),
        ...resources.map(resource => columns.map(k => resource[k] === undefined ? null : resource[k]).join('    \t'))
    ].join('\n');
    const ui = cliui({ width: windowSize.get().width });
    ui.div(out);
    console.log(ui.toString());
})
    .argv;
